aboutsummaryrefslogtreecommitdiff
path: root/gn3/db
diff options
context:
space:
mode:
authorBonfaceKilz2021-05-19 21:44:58 +0300
committerzsloan2021-06-18 22:08:04 +0000
commita1f48d95f17e939512fa9c276caf39d9f75878f9 (patch)
tree7d43d5f32cc4dbc2a83451774fc0b8d683b12f1b /gn3/db
parentdfafb7c11cb4f57c7e1a61de2ce2f1b62e1018be (diff)
downloadgenenetwork3-a1f48d95f17e939512fa9c276caf39d9f75878f9.tar.gz
db: phenotypes: Put mapping def after dataclass
Diffstat (limited to 'gn3/db')
-rw-r--r--gn3/db/phenotypes.py26
1 files changed, 13 insertions, 13 deletions
diff --git a/gn3/db/phenotypes.py b/gn3/db/phenotypes.py
index 645c0af..be5fb7b 100644
--- a/gn3/db/phenotypes.py
+++ b/gn3/db/phenotypes.py
@@ -56,20 +56,20 @@ class PublishXRef:
comments: Optional[str] = None
# Mapping from the Phenotype dataclass to the actual column names in the
# database
-phenotype_column_mapping = {
- "id_": "id",
- "pre_pub_description": "Pre_publication_description",
- "post_pub_description": "Post_publication_description",
- "original_description": "Original_description",
- "units": "Units",
- "pre_pub_abbrevition": "Pre_publication_abbreviation",
- "post_pub_abbreviation": "Post_publication_abbreviation",
- "lab_code": "Lab_code",
- "submitter": "Submitter",
- "owner": "Owner",
- "authorized_users": "Authorized_Users",
+publish_x_ref_mapping = {
+ "id_": "Id",
+ "inbred_set_id": "InbredSetId",
+ "phenotype_id": "PhenotypeId",
+ "publication_id": "PublicationId",
+ "data_id": "DataId",
+ "mean": "mean",
+ "locus": "locus",
+ "lrs": "lrs",
+ "additive": "additive",
+ "sequence": "sequence",
+ "comments": "comments",
}
@@ -56,20 +56,20 @@ class PublishXRef:
comments: Optional[str] = None
-# Mapping from the Phenotype dataclass to the actual column names in the
+# Mapping from the PublishXRef dataclass to the actual column names in the
# database